==> plsql-maven-shared-1.4-sources.jar: com/google/code/plsqlmaven/shared/PlSqlUtils.java <==
//
// Generated stub from file:/Users/andrea/Progetti/oss/googlecode/plsqlmaven/svn/trunk/target/checkout/plsql-maven-shared/src/main/groovy/com/google/code/plsqlmaven/shared/PlSqlUtils.groovy
//

package com.google.code.plsqlmaven.shared;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import java.math.BigDecimal;
import java.math.BigInteger;
import groovy.sql.Sql;

/**
 * Basic mojo to extend for PL/SQL Goals
 */
public class PlSqlUtils
    extends java.lang.Object
    implements groovy.lang.GroovyObject
{
    public static final java.lang.Object PLSQL_EXTENSION = null;

    private java.lang.Object ant = null;

    private Sql sql = null;

    private java.lang.Object log = null;

    /**
     * Magic constructor
     */
    private PlSqlUtils(java.lang.Void void0, java.lang.Void void1, java.lang.Void void2) {
        throw new InternalError("Stubbed method");
    }

    public PlSqlUtils(java.lang.Object ant, java.lang.Object log) {
        this((java.lang.Void)null, (java.lang.Void)null, (java.lang.Void)null);
        throw new InternalError("Stubbed method");
    }

    public PlSqlUtils(java.lang.Object ant, java.lang.Object log, java.lang.Object sql) {
        this((java.lang.Void)null, (java.lang.Void)null, (java.lang.Void)null);
        throw new InternalError("Stubbed method");
    }

    public void setSql(java.lang.Object sql) {
        throw new InternalError("Stubbed method");
    }

    public static java.lang.Object getSourceDescriptor(File source) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getPlsqlSourceFiles(java.lang.Object dir) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getTypeExt(java.lang.Object type) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object compile(File source) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object compileDirectory(java.lang.String dirPath) {
        throw new InternalError("Stubbed method");
    }

    public void deployJar(java.lang.Object jarPath) {
        throw new InternalError("Stubbed method");
    }

    public groovy.lang.MetaClass getMetaClass() {
        throw new InternalError("Stubbed method");
    }

    public void setMetaClass(groovy.lang.MetaClass metaClass) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object invokeMethod(java.lang.String name, java.lang.Object args) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getProperty(java.lang.String name) {
        throw new InternalError("Stubbed method");
    }

    public void setProperty(java.lang.String name, java.lang.Object value) {
        throw new InternalError("Stubbed method");
    }
}

==> plsql-maven-shared-1.10-sources.jar: com/google/code/plsqlmaven/shared/PlSqlUtils.java <==
//
// Generated stub from file:/Users/andrea/Progetti/oss/googlecode/plsqlmaven/svn/trunk/target/checkout/plsql-maven-shared/src/main/groovy/com/google/code/plsqlmaven/shared/PlSqlUtils.groovy
//

package com.google.code.plsqlmaven.shared;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import java.math.BigDecimal;
import java.math.BigInteger;
import groovy.sql.Sql;
import java.sql.SQLException;

/**
 * Basic mojo to extend for PL/SQL Goals
 */
public class PlSqlUtils
    extends java.lang.Object
    implements groovy.lang.GroovyObject
{
    public static final java.lang.Object PLSQL_EXTENSION = null;

    private java.lang.Object ant = null;

    private Sql sql = null;

    private java.lang.Object log = null;

    private java.lang.Object dropForceTypes = null;

    /**
     * Magic constructor
     */
    private PlSqlUtils(java.lang.Void void0, java.lang.Void void1, java.lang.Void void2) {
        throw new InternalError("Stubbed method");
    }

    public PlSqlUtils(java.lang.Object ant, java.lang.Object log, java.lang.Object dropForceTypes) {
        this((java.lang.Void)null, (java.lang.Void)null, (java.lang.Void)null);
        throw new InternalError("Stubbed method");
    }

    public PlSqlUtils(java.lang.Object ant, java.lang.Object log, java.lang.Object sql, java.lang.Object dropForceTypes) {
        this((java.lang.Void)null, (java.lang.Void)null, (java.lang.Void)null);
        throw new InternalError("Stubbed method");
    }

    public void setSql(java.lang.Object sql) {
        throw new InternalError("Stubbed method");
    }

    public static java.lang.Object getSourceDescriptor(File source) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getPlsqlSourceFiles(java.lang.Object dir) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getTypeExt(java.lang.Object type) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object compile(File source) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object compileDirectory(java.lang.String dirPath) {
        throw new InternalError("Stubbed method");
    }

    public void deployJar(java.lang.Object jarPath) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object extractFile(java.lang.Object targetDir, java.lang.Object name, java.lang.Object type) {
        throw new InternalError("Stubbed method");
    }

    private java.lang.Object extract(java.lang.Object name, java.lang.Object type, java.lang.Object file) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object get_dir(java.lang.Object base, java.lang.Object name) {
        throw new InternalError("Stubbed method");
    }

    private java.lang.Object extractView(java.lang.Object name, java.lang.Object file) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object sid(java.lang.Object oracleIdentifier) {
        throw new InternalError("Stubbed method");
    }

    public groovy.lang.MetaClass getMetaClass() {
        throw new InternalError("Stubbed method");
    }

    public void setMetaClass(groovy.lang.MetaClass metaClass) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object invokeMethod(java.lang.String name, java.lang.Object args) {
        throw new InternalError("Stubbed method");
    }

    public java.lang.Object getProperty(java.lang.String name) {
        throw new InternalError("Stubbed method");
    }

    public void setProperty(java.lang.String name, java.lang.Object value) {
        throw new InternalError("Stubbed method");
    }
}
